@@ -1,6 +1,6 @@
 #!/usr/bin/ruby
 # DocDiff
-# 2002-06-27 Thu ... 2003-04-11 Sun
+# 2002-06-27 Thu ... 2003-08-29 Sun
 # Hisashi MORITA
 # requirement for runtime: Ruby (> 1.6), diff library by akr (included in Ruby/CVS),
 # requirement for testing: above plus Uconv by Yoshidam
@@ -12,7 +12,7 @@ require 'optparse'
 
 class DocDiff
 
-  AppVersion = '0.3.0'
+  AppVersion = '0.3.1'
   Author = "Copyright (C) 2002-2004 Hisashi MORITA.\n" +
            "diff library originates from Ruby/CVS by TANAKA Akira.\n"
   License = "This software is licensed under so-called modified BSD license.\n" +
@@ -236,6 +236,9 @@ if $0 == __FILE__
     o.def_option('--wdiff', 'same as --format=wdiff'){clo[:format] = "wdiff"}
     o.def_option('--stat', 'same as --format=stat (not supported yet)'){clo[:format] = "stat"}
 
+    o.def_option('--label LABEL', '-L LABEL',
+                 'Use label instead of filename (not supported yet)'){|clo[:label1], clo[:label2]|}
+
     o.def_option('--digest', 'digest output, do not show all'){clo[:digest] = true}
     o.def_option('--summary', 'same as --digest'){clo[:digest] = true}
     o.def_option('--cache', 'use file cache (not supported yet)'){clo[:cache] = true}
